package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Mar 13, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CodeMsg struct {
Code int `json:"code" example:"0"`
Msg string `json:"msg" example:"success"`
}
type MultiData[T any] struct {
CodeMsg
Data []T `json:"data"`
}
type Page struct {
TotalCount int64 `json:"total_count" example:"100"`
TotalPage int64 `json:"total_page" example:"10"`
PageCount int64 `json:"page_count" example:"10"`
PageIndex int64 `json:"page_index" example:"3"`
Sort string `json:"sort"`
}
type SingleData[T any] struct {
CodeMsg
Data T `json:"data"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.